@@ -1,8 +1,8 @@
 #!/usr/bin/env python
-# $Id: servers.py 1239 2013-12-08 21:40:25Z g.rodola $
+# $Id: servers.py 1262 2014-04-11 22:13:10Z g.rodola $
 
 #  ======================================================================
-#  Copyright (C) 2007-2013 Giampaolo Rodola' <g.rodola@gmail.com>
+#  Copyright (C) 2007-2014 Giampaolo Rodola' <g.rodola@gmail.com>
 #
 #                         All Rights Reserved
 #
@@ -77,6 +77,7 @@ from pyftpdlib.ioloop import Acceptor, IOLoop
 __all__ = ['FTPServer']
 _BSD = 'bsd' in sys.platform
 
+
 # ===================================================================
 # --- base class
 # ===================================================================
@@ -160,7 +161,7 @@ class FTPServer(Acceptor):
             return self._map_len() <= self.max_cons
 
     def _log_start(self):
-        if not logging.getLogger().handlers:
+        if not logging.getLogger('pyftpdlib').handlers:
             # If we get to this point it means the user hasn't
             # configured logger. We want to log by default so
             # we configure logging ourselves so that it will
@@ -199,7 +200,7 @@ class FTPServer(Acceptor):
            Also, logs server start and stop.
         """
         if handle_exit:
-            log = handle_exit and blocking == True
+            log = handle_exit and blocking
             if log:
                 self._log_start()
             try:
@@ -208,8 +209,9 @@ class FTPServer(Acceptor):
                 pass
             if blocking:
                 if log:
-                    logger.info(">>> shutting down FTP server (%s active fds) <<<",
-                                self._map_len())
+                    logger.info(
+                        ">>> shutting down FTP server (%s active fds) <<<",
+                        self._map_len())
                 self.close_all()
         else:
             self.ioloop.loop(timeout, blocking)
@@ -328,8 +330,8 @@ class _SpawnerBase(FTPServer):
             poll_timeout = getattr(self, 'poll_timeout', None)
             soonest_timeout = poll_timeout
 
-            while (ioloop.socket_map or ioloop.sched._tasks) and not \
-              self._exit.is_set():
+            while (ioloop.socket_map or ioloop.sched._tasks) and \
+                    not self._exit.is_set():
                 try:
                     if ioloop.socket_map:
                         poll(timeout=soonest_timeout)
@@ -342,9 +344,11 @@ class _SpawnerBase(FTPServer):
                         # functions are supposed to be cancel()ed on close()
                         # but by using threads we can incur into
                         # synchronization issues such as this one.
-                        # https://code.google.com/p/pyftpdlib/issues/detail?id=245
+                        # https://code.google.com/p/pyftpdlib/issues/
+                        #     detail?id=245
                         if not ioloop.socket_map:
-                            ioloop.sched.reheapify() # get rid of cancel()led calls
+                            # get rid of cancel()led calls
+                            ioloop.sched.reheapify()
                             soonest_timeout = sched_poll()
                             if soonest_timeout:
                                 time.sleep(min(soonest_timeout, 1))
@@ -374,8 +378,8 @@ class _SpawnerBase(FTPServer):
                         raise
                 else:
                     if poll_timeout:
-                        if soonest_timeout is None \
-                        or soonest_timeout > poll_timeout:
+                        if (soonest_timeout is None
+                                or soonest_timeout > poll_timeout):
                             soonest_timeout = poll_timeout
         finally:
             ioloop.close()
@@ -413,7 +417,7 @@ class _SpawnerBase(FTPServer):
     def serve_forever(self, timeout=None, blocking=True, handle_exit=True):
         self._exit.clear()
         if handle_exit:
-            log = handle_exit and blocking == True
+            log = handle_exit and blocking
             if log:
                 self._log_start()
             try:
@@ -422,8 +426,9 @@ class _SpawnerBase(FTPServer):
                 pass
             if blocking:
                 if log:
-                    logger.info(">>> shutting down FTP server (%s active " \
-                                "workers) <<<", self._map_len())
+                    logger.info(
+                        ">>> shutting down FTP server (%s active workers) <<<",
+                        self._map_len())
                 self.close_all()
         else:
             self.ioloop.loop(timeout, blocking)
